==> jc-1.4.0.tar.gz: soot/util/SingletonList.h <==
// public class soot.util.SingletonList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class da1b10f740921fee soot_util_SingletonList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_soot_util_SingletonList_H_
#define _JC_soot_util_SingletonList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_util_SingletonList$sub_refs	_jc_soot_util_SingletonList$sub_refs;
typedef struct _jc_soot_util_SingletonList$sub_nonrefs	_jc_soot_util_SingletonList$sub_nonrefs;
typedef struct _jc_soot_util_SingletonList$refs	_jc_soot_util_SingletonList$refs;
typedef struct _jc_soot_util_SingletonList$nonrefs	_jc_soot_util_SingletonList$nonrefs;
typedef struct _jc_soot_util_SingletonList$object	_jc_soot_util_SingletonList$object;

typedef const struct _jc_soot_util_SingletonList$vmethods	_jc_soot_util_SingletonList$vmethods;
typedef const struct _jc_soot_util_SingletonList$vtable	_jc_soot_util_SingletonList$vtable;
typedef const struct _jc_soot_util_SingletonList$vtype	_jc_soot_util_SingletonList$vtype;

// Constructors
extern void _jc_soot_util_SingletonList$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_util_SingletonList$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_soot_util_SingletonList$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_soot_util_SingletonList$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_SingletonList$method$get$a706240e1333824b(_jc_env *, struct _jc_soot_util_SingletonList$object *, jint);
extern jint _jc_soot_util_SingletonList$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_util_SingletonList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_SingletonList$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_soot_util_SingletonList$method_info$get$a706240e1333824b;
extern _jc_method _jc_soot_util_SingletonList$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_util_SingletonList$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_soot_util_SingletonList$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_soot_util_SingletonList$object *, jint);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_util_SingletonList$object *);
};

// Vtable
struct _jc_soot_util_SingletonList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_soot_util_SingletonList$vmethods	soot_util_SingletonList;
};

// Vtype
struct _jc_soot_util_SingletonList$vtype {
	_jc_type			type;
	_jc_soot_util_SingletonList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SingletonList$sub_refs {
	struct _jc_java_lang_Object$object	*o;
};

// Reference instance fields (object)
struct _jc_soot_util_SingletonList$refs {
    _jc_soot_util_SingletonList$sub_refs	soot_util_SingletonList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SingletonList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SingletonList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_soot_util_SingletonList$sub_nonrefs	soot_util_SingletonList;
};

// Object instance structure
struct _jc_soot_util_SingletonList$object {
	_jc_soot_util_SingletonList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SingletonList$vtype	*vtype;
	_jc_soot_util_SingletonList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SingletonList$vtype _jc_soot_util_SingletonList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SingletonList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SingletonList$class_object;

#endif	/* _JC_soot_util_SingletonList_H_ */

==> jc-1.4.6.tar.gz: soot/util/SingletonList.h <==
// public class soot.util.SingletonList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class da1b10f740921fee soot_util_SingletonList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_soot_util_SingletonList_H_
#define _JC_soot_util_SingletonList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_util_SingletonList$sub_refs	_jc_soot_util_SingletonList$sub_refs;
typedef struct _jc_soot_util_SingletonList$sub_nonrefs	_jc_soot_util_SingletonList$sub_nonrefs;
typedef struct _jc_soot_util_SingletonList$refs	_jc_soot_util_SingletonList$refs;
typedef struct _jc_soot_util_SingletonList$nonrefs	_jc_soot_util_SingletonList$nonrefs;
typedef struct _jc_soot_util_SingletonList$object	_jc_soot_util_SingletonList$object;

typedef const struct _jc_soot_util_SingletonList$vmethods	_jc_soot_util_SingletonList$vmethods;
typedef const struct _jc_soot_util_SingletonList$vtable	_jc_soot_util_SingletonList$vtable;
typedef const struct _jc_soot_util_SingletonList$vtype	_jc_soot_util_SingletonList$vtype;

// Constructors
extern void _jc_soot_util_SingletonList$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_util_SingletonList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_SingletonList$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_soot_util_SingletonList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_SingletonList$method$get$a706240e1333824b(_jc_env *, struct _jc_soot_util_SingletonList$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_util_SingletonList$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_util_SingletonList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_SingletonList$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_soot_util_SingletonList$method_info$get$a706240e1333824b;
extern _jc_method _jc_soot_util_SingletonList$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_util_SingletonList$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_soot_util_SingletonList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_soot_util_SingletonList$object *, jint) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_util_SingletonList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_SingletonList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_soot_util_SingletonList$vmethods	soot_util_SingletonList;
};

// Vtype
struct _jc_soot_util_SingletonList$vtype {
	_jc_type			type;
	_jc_soot_util_SingletonList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SingletonList$sub_refs {
	struct _jc_java_lang_Object$object	*o;
};

// Reference instance fields (object)
struct _jc_soot_util_SingletonList$refs {
    _jc_soot_util_SingletonList$sub_refs	soot_util_SingletonList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SingletonList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SingletonList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_soot_util_SingletonList$sub_nonrefs	soot_util_SingletonList;
};

// Object instance structure
struct _jc_soot_util_SingletonList$object {
	_jc_soot_util_SingletonList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SingletonList$vtype	*vtype;
	_jc_soot_util_SingletonList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SingletonList$vtype _jc_soot_util_SingletonList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SingletonList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SingletonList$class_object;

#endif	/* _JC_soot_util_SingletonList_H_ */
